@@ -6,12 +6,12 @@
 #include <QMainWindow>
 #include <QSettings>
 #include <QMaemo5InformationBox>
-#include <QMessageBox>
 #include <QShortcut>
 
 #include "ui_bookmarkswindow.h"
 #include "descriptivedelegate.h"
 #include "filesystemmodel.h"
+#include "confirmdialog.h"
 
 namespace Ui {
     class BookmarksWindow;
