@@ -23,6 +23,7 @@
 #include "filedetailsdialog.h"
 #include "operationmanager.h"
 #include "clipboard.h"
+#include "confirmdialog.h"
 
 class FileListView : public QListView
 {
@@ -34,13 +35,21 @@ public:
     QString currentPath();
 
     void setDetails(FileSystemModel::Detail firstDetail, FileSystemModel::Detail secondDetail);
+
 public slots:
     void openPath(QString path);
+
     void enableHidden(bool enable);
     void enableThumbnails(bool enable);
     void enableLocationItem(bool enable);
     void enableMultiSelection(bool enable);
     void enableGridMode(bool enable);
+
+    void sortByName();
+    void sortByTime();
+    void sortBySize();
+    void sortByType();
+
     void clipSelected();
     void openSelected();
     void deleteSelected();
