@@ -255,7 +255,7 @@ void MainWindow::closeSearch()
 void MainWindow::onLocationChanged(QString path)
 {
     closeSearch();
-    ui->browserList->enableMultiSelection(false);
+    ui->selectionToggleButton->setChecked(false);
     ui->locationWidget->setLocation(path);
     ui->locationLabel->setText(QFontMetrics(ui->locationLabel->font()).elidedText(path, Qt::ElideLeft, ui->locationLabel->width()));
 }
